pub struct ZcosmicOutputConfigurationV1 { /* private fields */ }wayland and Linux only.Expand description
Output configuration extension object
Extension to zwlr_output_configuration_v1.
Adds additional parameters to be tested/applyed via the original zwlr_output_configuration_v1.
See also the Event enum for this interface.
Implementations
Sourceimpl ZcosmicOutputConfigurationV1
impl ZcosmicOutputConfigurationV1
Sourcepub fn mirror_head<U, D>(
&self,
head: &ZwlrOutputHeadV1,
mirroring: &ZwlrOutputHeadV1,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrOutputConfigurationHeadV1
pub fn mirror_head<U, D>( &self, head: &ZwlrOutputHeadV1, mirroring: &ZwlrOutputHeadV1, qh: &QueueHandle<D>, udata: U, ) -> ZwlrOutputConfigurationHeadV1
enable and configure a head to mirror another head
Enable a head mirroring another.
This request creates a head configuration object that can be used to change the head’s properties.
This is an alternative to zwlr_output_configuration_v1::enable_head or zwlr_output_configuration_v1::disable_head
Using either with the same head argument will result in an already_configured_head error on the original
zwlr_output_configuration_v1 object.
All properties are still required to be set to the resulting zwlr_output_configuration_head by the client
as denoted in the original protocol. Some like set_position however might be ignored in mirroring configurations.
Trying to set a disabled or mirroring head as mirroring or calling disable_head/mirror_head after using a head
as a mirroring argument will raise a mirrored_head_busy protocol error.